@@ -255,6 +255,7 @@ pub fn tab_line(
     cols: usize,
     palette: Palette,
     capabilities: PluginCapabilities,
+    hide_session_name: bool,
     mode: InputMode,
     active_swap_layout_name: &Option<String>,
     is_swap_layout_dirty: bool,
@@ -266,7 +267,10 @@ pub fn tab_line(
     } else {
         tabs_before_active.pop().unwrap()
     };
-    let mut prefix = tab_line_prefix(session_name, mode, palette, cols);
+    let mut prefix = match hide_session_name {
+        true => tab_line_prefix(None, mode, palette, cols),
+        false => tab_line_prefix(session_name, mode, palette, cols),
+    };
     let prefix_len = get_current_title_len(&prefix);
 
     // if active tab alone won't fit in cols, don't draw any tabs
