@@ -7,7 +7,7 @@ use crate::{
     ClientId, ServerInstruction,
 };
 use async_std::task::{self, JoinHandle};
-use std::{collections::HashMap, env, os::unix::io::RawFd, path::PathBuf};
+use std::{collections::HashMap, os::unix::io::RawFd, path::PathBuf};
 use zellij_utils::nix::unistd::Pid;
 use zellij_utils::{
     async_std,
@@ -48,6 +48,7 @@ pub enum PtyInstruction {
     UpdateActivePane(Option<PaneId>, ClientId),
     GoToTab(TabIndex, ClientId),
     NewTab(
+        Option<PathBuf>,
         Option<TerminalAction>,
         Option<TiledPaneLayout>,
         Vec<FloatingPaneLayout>,
@@ -336,6 +337,7 @@ pub(crate) fn pty_thread_main(mut pty: Pty, layout: Box<Layout>) -> Result<()> {
                     })?;
             },
             PtyInstruction::NewTab(
+                cwd,
                 terminal_action,
                 tab_layout,
                 floating_panes_layout,
@@ -351,6 +353,7 @@ pub(crate) fn pty_thread_main(mut pty: Pty, layout: Box<Layout>) -> Result<()> {
                     floating_panes_layout
                 };
                 pty.spawn_terminals_for_layout(
+                    cwd,
                     tab_layout.unwrap_or_else(|| layout.new_tab().0),
                     floating_panes_layout,
                     terminal_action.clone(),
@@ -465,10 +468,7 @@ impl Pty {
                 default_shell
             },
             None => {
-                let shell = PathBuf::from(env::var("SHELL").unwrap_or_else(|_| {
-                    log::warn!("Cannot read SHELL env, falling back to use /bin/sh");
-                    "/bin/sh".to_string()
-                }));
+                let shell = get_default_shell();
                 TerminalAction::RunCommand(RunCommand {
                     args: vec![],
                     command: shell,
@@ -591,6 +591,7 @@ impl Pty {
     }
     pub fn spawn_terminals_for_layout(
         &mut self,
+        cwd: Option<PathBuf>,
         layout: TiledPaneLayout,
         floating_panes_layout: Vec<FloatingPaneLayout>,
         default_shell: Option<TerminalAction>,
@@ -601,7 +602,7 @@ impl Pty {
         let err_context = || format!("failed to spawn terminals for layout for client {client_id}");
 
         let mut default_shell =
-            default_shell.unwrap_or_else(|| self.get_default_terminal(None, None));
+            default_shell.unwrap_or_else(|| self.get_default_terminal(cwd, None));
         self.fill_cwd(&mut default_shell, client_id);
         let extracted_run_instructions = layout.extract_run_instructions();
         let extracted_floating_run_instructions =
@@ -738,7 +739,7 @@ impl Pty {
             }
         });
         match run_instruction {
-            Some(Run::Command(command)) => {
+            Some(Run::Command(mut command)) => {
                 let starts_held = command.hold_on_start;
                 let hold_on_close = command.hold_on_close;
                 let quit_cb = Box::new({
@@ -758,6 +759,11 @@ impl Pty {
                         }
                     }
                 });
+                if command.cwd.is_none() {
+                    if let TerminalAction::RunCommand(cmd) = default_shell {
+                        command.cwd = cmd.cwd;
+                    }
+                }
                 let cmd = TerminalAction::RunCommand(command.clone());
                 if starts_held {
                     // we don't actually open a terminal in this case, just wait for the user to run it
@@ -1039,3 +1045,10 @@ fn send_command_not_found_to_screen(
         .with_context(err_context)?;
     Ok(())
 }
+
+pub fn get_default_shell() -> PathBuf {
+    PathBuf::from(std::env::var("SHELL").unwrap_or_else(|_| {
+        log::warn!("Cannot read SHELL env, falling back to use /bin/sh");
+        "/bin/sh".to_string()
+    }))
+}
