@@ -83,9 +83,6 @@ pub enum ConfigError {
     KdlDeserializationError(#[from] kdl::KdlError),
     #[error("KdlDeserialization error: {0}")]
     KdlError(KdlError), // TODO: consolidate these
-    // Io error
-    #[error("IoError: {0}")]
-    Io(#[from] io::Error),
     #[error("Config error: {0}")]
     Std(#[from] Box<dyn std::error::Error>),
     // Io error with path context
@@ -303,6 +300,7 @@ mod config_test {
             theme "my cool theme"
             default_mode "locked"
             default_shell "/path/to/my/shell"
+            default_cwd "/path"
             default_layout "/path/to/my/layout.kdl"
             layout_dir "/path/to/my/layout-dir"
             theme_dir "/path/to/my/theme-dir"
@@ -339,6 +337,11 @@ mod config_test {
             Some(PathBuf::from("/path/to/my/shell")),
             "Option set in config"
         );
+        assert_eq!(
+            config.options.default_cwd,
+            Some(PathBuf::from("/path")),
+            "Option set in config"
+        );
         assert_eq!(
             config.options.default_layout,
             Some(PathBuf::from("/path/to/my/layout.kdl")),
