@@ -207,7 +207,7 @@ impl Run {
     }
 }
 
-#[derive(Debug, Serialize, Deserialize, Clone, PartialEq, Eq)]
+#[derive(Debug, Serialize, Deserialize, Clone, PartialEq, Eq, Hash)]
 pub struct RunPlugin {
     #[serde(default)]
     pub _allow_exec_host_cmd: bool,
@@ -221,7 +221,7 @@ pub enum RunPluginLocation {
 }
 
 impl RunPluginLocation {
-    pub fn parse(location: &str) -> Result<Self, PluginsConfigError> {
+    pub fn parse(location: &str, cwd: Option<PathBuf>) -> Result<Self, PluginsConfigError> {
         let url = Url::parse(location)?;
 
         let decoded_path = percent_encoding::percent_decode_str(url.path()).decode_utf8_lossy();
@@ -233,16 +233,29 @@ impl RunPluginLocation {
                     // Path is absolute, its safe to use URL path.
                     //
                     // This is the case if the scheme and : delimiter are followed by a / slash
-                    decoded_path
+                    PathBuf::from(decoded_path.as_ref())
+                } else if location.starts_with("file:~") {
+                    // Unwrap is safe here since location is a valid URL
+                    PathBuf::from(location.strip_prefix("file:").unwrap())
                 } else {
                     // URL dep doesn't handle relative paths with `file` schema properly,
                     // it always makes them absolute. Use raw location string instead.
                     //
                     // Unwrap is safe here since location is a valid URL
-                    location.strip_prefix("file:").unwrap().into()
+                    let stripped = location.strip_prefix("file:").unwrap();
+                    match cwd {
+                        Some(cwd) => cwd.join(stripped),
+                        None => PathBuf::from(stripped),
+                    }
                 };
-
-                Ok(Self::File(PathBuf::from(path.as_ref())))
+                let path = match shellexpand::full(&path.to_string_lossy().to_string()) {
+                    Ok(s) => PathBuf::from(s.as_ref()),
+                    Err(e) => {
+                        log::error!("Failed to shell expand plugin path: {}", e);
+                        path
+                    },
+                };
+                Ok(Self::File(path))
             },
             _ => Err(PluginsConfigError::InvalidUrlScheme(url)),
         }
@@ -395,6 +408,7 @@ pub struct TiledPaneLayout {
     pub external_children_index: Option<usize>,
     pub children_are_stacked: bool,
     pub is_expanded_in_stack: bool,
+    pub exclude_from_sync: Option<bool>,
 }
 
 impl TiledPaneLayout {
@@ -729,7 +743,9 @@ impl Layout {
         let swap_layout_and_path = Layout::swap_layout_and_path(&layout_path);
 
         let mut kdl_layout = String::new();
-        layout_file.read_to_string(&mut kdl_layout)?;
+        layout_file
+            .read_to_string(&mut kdl_layout)
+            .map_err(|e| ConfigError::IoPath(e, layout_path.into()))?;
         Ok((
             layout_path.as_os_str().to_string_lossy().into(),
             kdl_layout,
