@@ -1766,11 +1766,8 @@ impl Themes {
         Ok(themes)
     }
 
-    pub fn from_path(path_to_theme_file: PathBuf) -> Result<Self, ConfigError> {
-        // String is the theme name
-        let kdl_config = std::fs::read_to_string(&path_to_theme_file)
-            .map_err(|e| ConfigError::IoPath(e, path_to_theme_file.into()))?;
-        let kdl_config: KdlDocument = kdl_config.parse()?;
+    pub fn from_string(raw_string: String) -> Result<Self, ConfigError> {
+        let kdl_config: KdlDocument = raw_string.parse()?;
         let kdl_themes = kdl_config.get("themes").ok_or(ConfigError::new_kdl_error(
             "No theme node found in file".into(),
             kdl_config.span().offset(),
@@ -1780,6 +1777,13 @@ impl Themes {
         Ok(all_themes_in_file)
     }
 
+    pub fn from_path(path_to_theme_file: PathBuf) -> Result<Self, ConfigError> {
+        // String is the theme name
+        let kdl_config = std::fs::read_to_string(&path_to_theme_file)
+            .map_err(|e| ConfigError::IoPath(e, path_to_theme_file.into()))?;
+        Themes::from_string(kdl_config)
+    }
+
     pub fn from_dir(path_to_theme_dir: PathBuf) -> Result<Self, ConfigError> {
         let mut themes = Themes::default();
         for entry in std::fs::read_dir(&path_to_theme_dir)
